Module simplebyteunit

Module simplebyteunit 

Fast, stupid simple ByteUnit implementation

Provides a simple way to encapsulate primitives as byteunits.

Enums

ByteUnit
Thin encapsulate of a supported, primitive integer to provide simple byteunit facilities
Error

Constants

B
Base unit
E
Power of 6 (Exa/Exbi)
G
Power of 3 (Giga/Gibi)
IEC
IEC ByteUnit (x*1024)
K
Power of 1 (Kilo/Kibi)
M
Power of 2 (Mega/Mebi)
MAX
Maximum supported power
P
Power of 5 (Peta/Pebi)
SI
SI ByteUnit (x*1000)
T
Power of 4 (Tera/Tebi)

Traits

ToByteUnit
Trait providing generic abstraction to encapsulate primitive in a ByteUnit