pub trait ToByteUnit<T: Copy> {
// Required method
fn to_byteunit(self, byte: ByteUnit<()>) -> ByteUnit<T>;
}Expand description
Trait providing generic abstraction to encapsulate primitive in a ByteUnit
pub trait ToByteUnit<T: Copy> {
// Required method
fn to_byteunit(self, byte: ByteUnit<()>) -> ByteUnit<T>;
}Trait providing generic abstraction to encapsulate primitive in a ByteUnit